@@ -24,6 +24,10 @@ Used for tasks that create a file.
         flags => { %flags },
     );
 
+=head1 METHODS
+
+=over 4
+
 =cut
 
 #}}}
@@ -31,6 +35,12 @@ Used for tasks that create a file.
 use base 'App::PPBuild::Task';
 use Carp;
 
+=item hook_completed()
+
+Use hook_completed to verify a file with the name of the task exists.
+
+=cut
+
 sub hook_completed {
     my $self = shift;
     my ( $exitref ) = shift;
@@ -40,6 +50,12 @@ sub hook_completed {
     }
 }
 
+=item ran()
+
+Override ran() to return true (1) if a file with the name of th task exisits.
+
+=cut
+
 sub ran {
     my $self = shift;
     return 1 if ( -e $self->name );
@@ -50,6 +66,8 @@ sub ran {
 
 __END__
 
+=back
+
 =head1 AUTHOR
 
 Chad Granum E<lt>exodist7@gmail.comE<gt>
